## [v0.26.2](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.26.2) - 2024-12-02

### Fix

* Improve pinning for numpy and pandas ([#90](https://github.com/DS4SD/deepsearch-glm/issues/90)) ([`fe16932`](https://github.com/DS4SD/deepsearch-glm/commit/fe1693202bfaaa6eb34d868ff4382ea8ece9c107))
* README badges ([#85](https://github.com/DS4SD/deepsearch-glm/issues/85)) ([`f929929`](https://github.com/DS4SD/deepsearch-glm/commit/f92992902dfe1ef501f736efa5477cdad2118867))

## [v0.26.1](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.26.1) - 2024-10-22

### Fix

* Remove old dependencies or more to extras ([#87](https://github.com/DS4SD/deepsearch-glm/issues/87)) ([`90b2c7f`](https://github.com/DS4SD/deepsearch-glm/commit/90b2c7f65854f22d35d8d5b4b1ef459d2a7012d5))

## [v0.26.0](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.26.0) - 2024-10-21

### Feature

* Disambiguate section headings and list items from text items in DoclingDocument ([#86](https://github.com/DS4SD/deepsearch-glm/issues/86)) ([`d2b1e60`](https://github.com/DS4SD/deepsearch-glm/commit/d2b1e60d79d961c53889016eff06536a97ec31ee))

## [v0.25.0](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.25.0) - 2024-10-16

### Feature

* Support new docling-core format ([#74](https://github.com/DS4SD/deepsearch-glm/issues/74)) ([`739eecb`](https://github.com/DS4SD/deepsearch-glm/commit/739eecb2c82a95a188faa8172dc659c2b45dae37))

## [v0.24.0](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.24.0) - 2024-10-10

### Feature

* Add support for python 3.13 ([#82](https://github.com/DS4SD/deepsearch-glm/issues/82)) ([`d4e3962`](https://github.com/DS4SD/deepsearch-glm/commit/d4e39623867a9c5feab39de5535385b93c4e7d37))

## [v0.23.0](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.23.0) - 2024-10-09

### Feature

* Add sdist and build only with system deps ([#81](https://github.com/DS4SD/deepsearch-glm/issues/81)) ([`ed69808`](https://github.com/DS4SD/deepsearch-glm/commit/ed698084b13594758c8b7419e3d1ab37f69cfa49))

## [v0.22.0](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.22.0) - 2024-10-02

### Feature

* Support for Windows ([#79](https://github.com/DS4SD/deepsearch-glm/issues/79)) ([`5af213a`](https://github.com/DS4SD/deepsearch-glm/commit/5af213a1f25f0c683b1139c2dcf0b2a1c0f8e29d))

## [v0.21.1](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.21.1) - 2024-09-17

### Fix

* Propagate cell type ([#73](https://github.com/DS4SD/deepsearch-glm/issues/73)) ([`27c5852`](https://github.com/DS4SD/deepsearch-glm/commit/27c58526b68be4039d96f6f0001fa53b54e9f1ea))

## [v0.21.0](https://github.com/DS4SD/deepsearch-glm/releases/tag/v0.21.0) - 2024-09-10

### Feature

* Make deepsearch-toolkit optional ([#71](https://github.com/DS4SD/deepsearch-glm/issues/71)) ([`f9e0a0e`](https://github.com/DS4SD/deepsearch-glm/commit/f9e0a0ef94528432e5a07eff291e1cb82ef27a5d))
